@@ -277,9 +277,8 @@ class TestTreeSchemas:
                         {
                             "token": None,
                             "tree": {
-                                "type": "single_requirement_indicator_expression",
+                                "type": "Muss",
                                 "children": [
-                                    {"token": {"value": "Muss", "type": "MODAL_MARK"}, "tree": None},
                                     {
                                         "token": None,
                                         "tree": {
@@ -337,7 +336,6 @@ class TestTreeSchemas:
                             "token": None,
                             "tree": {
                                 "children": [
-                                    {"token": {"value": "Soll", "type": "MODAL_MARK"}, "tree": None},
                                     {
                                         "token": None,
                                         "tree": {
@@ -427,17 +425,14 @@ class TestTreeSchemas:
                                         },
                                     },
                                 ],
-                                "type": "single_requirement_indicator_expression",
+                                "type": "Soll",
                             },
                         },
                         {
                             "token": None,
                             "tree": {
-                                "children": [
-                                    {"token": {"value": "Kann", "type": "MODAL_MARK"}, "tree": None},
-                                    {"token": {"value": "43", "type": "condition_key"}, "tree": None},
-                                ],
-                                "type": "single_requirement_indicator_expression",
+                                "children": [{"token": {"value": "43", "type": "condition_key"}, "tree": None}],
+                                "type": "Kann",
                             },
                         },
                     ],
